
#ifndef LIBKOPETE_EXPORT_H
#define LIBKOPETE_EXPORT_H

#ifdef LIBKOPETE_STATIC_DEFINE
#  define LIBKOPETE_EXPORT
#  define LIBKOPETE_NO_EXPORT
#else
#  ifndef LIBKOPETE_EXPORT
#    ifdef kopete_EXPORTS
        /* We are building this library */
#      define LIBKOPETE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define LIBKOPETE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef LIBKOPETE_NO_EXPORT
#    define LIBKOPETE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef LIBKOPETE_DEPRECATED
#  define LIBKOPETE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef LIBKOPETE_DEPRECATED_EXPORT
#  define LIBKOPETE_DEPRECATED_EXPORT LIBKOPETE_EXPORT LIBKOPETE_DEPRECATED
#endif

#ifndef LIBKOPETE_DEPRECATED_NO_EXPORT
#  define LIBKOPETE_DEPRECATED_NO_EXPORT LIBKOPETE_NO_EXPORT LIBKOPETE_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef LIBKOPETE_NO_DEPRECATED
#    define LIBKOPETE_NO_DEPRECATED
#  endif
#endif

#endif /* LIBKOPETE_EXPORT_H */
