<!DOCTYPE kpartgui>
<kpartgui name="kopete_otr" version="1">
	<MenuBar>
		<Menu name="edit">
			<text>&amp;Edit</text>
			<Action name="otr_policy" />
		</Menu>
	</MenuBar>
	<Menu name="contact_popup">
		<Action name="otr_policy" />
	</Menu>
</kpartgui>
